package com.shzg.project.worn.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.shzg.framework.aspectj.lang.annotation.Log;
import com.shzg.framework.aspectj.lang.enums.BusinessType;
import com.shzg.project.worn.domain.MqttTopicConfig;
import com.shzg.project.worn.service.IMqttTopicConfigService;
import com.shzg.framework.web.controller.BaseController;
import com.shzg.framework.web.domain.AjaxResult;
import com.shzg.common.utils.poi.ExcelUtil;
import com.shzg.framework.web.page.TableDataInfo;

/**
 * MQTT主题配置Controller
 * 
 * @author shzg
 * @date 2026-04-08
 */
@RestController
@RequestMapping("/worn/mqttConfig")
public class MqttTopicConfigController extends BaseController
{
    @Autowired
    private IMqttTopicConfigService mqttTopicConfigService;

    /**
     * 查询MQTT主题配置列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(MqttTopicConfig mqttTopicConfig)
    {
        startPage();
        List<MqttTopicConfig> list = mqttTopicConfigService.selectMqttTopicConfigList(mqttTopicConfig);
        return getDataTable(list);
    }

    /**
     * 导出MQTT主题配置列表
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttConfig:export')")
    @Log(title = "MQTT主题配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MqttTopicConfig mqttTopicConfig)
    {
        List<MqttTopicConfig> list = mqttTopicConfigService.selectMqttTopicConfigList(mqttTopicConfig);
        ExcelUtil<MqttTopicConfig> util = new ExcelUtil<MqttTopicConfig>(MqttTopicConfig.class);
        util.exportExcel(response, list, "MQTT主题配置数据");
    }

    /**
     * 获取MQTT主题配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(mqttTopicConfigService.selectMqttTopicConfigById(id));
    }

    /**
     * 新增MQTT主题配置
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttConfig:add')")
    @Log(title = "MQTT主题配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MqttTopicConfig mqttTopicConfig)
    {
        return toAjax(mqttTopicConfigService.insertMqttTopicConfig(mqttTopicConfig));
    }

    /**
     * 修改MQTT主题配置
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttConfig:edit')")
    @Log(title = "MQTT主题配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MqttTopicConfig mqttTopicConfig)
    {
        return toAjax(mqttTopicConfigService.updateMqttTopicConfig(mqttTopicConfig));
    }

    /**
     * 删除MQTT主题配置
     */
    @PreAuthorize("@ss.hasPermi('worn:mqttConfig:remove')")
    @Log(title = "MQTT主题配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(mqttTopicConfigService.deleteMqttTopicConfigByIds(ids));
    }
}
